@@ -2,7 +2,7 @@
 
 use std::{io, str::FromStr};
 
-use clap::App;
+use clap::Command;
 use clap_complete;
 use miette::{Diagnostic, SourceSpan};
 use quickcheck::{Arbitrary, Gen};
@@ -103,40 +103,40 @@ pub struct ShellFromStrError {
 }
 
 /// Print completion for the given shell
-pub fn print_completions(writer: &mut dyn io::Write, app: &mut App<'_>, shell: Shell) {
+pub fn print_completions(writer: &mut dyn io::Write, cmd: &mut Command<'_>, shell: Shell) {
     match shell {
         Shell::Bash => clap_complete::generate(
             clap_complete::shells::Bash,
-            app,
-            app.get_name().to_string(),
+            cmd,
+            cmd.get_name().to_string(),
             writer,
         ),
         Shell::Elvish => {
             clap_complete::generate(
                 clap_complete::shells::Elvish,
-                app,
-                app.get_name().to_string(),
+                cmd,
+                cmd.get_name().to_string(),
                 writer,
             );
         }
         Shell::Fish => clap_complete::generate(
             clap_complete::shells::Fish,
-            app,
-            app.get_name().to_string(),
+            cmd,
+            cmd.get_name().to_string(),
             writer,
         ),
         Shell::PowerShell => {
             clap_complete::generate(
                 clap_complete::shells::PowerShell,
-                app,
-                app.get_name().to_string(),
+                cmd,
+                cmd.get_name().to_string(),
                 writer,
             );
         }
         Shell::Zsh => clap_complete::generate(
             clap_complete::shells::Zsh,
-            app,
-            app.get_name().to_string(),
+            cmd,
+            cmd.get_name().to_string(),
             writer,
         ),
     }
